pygeodesy.ecefLocals

Package pygeodesy :: Module ecefLocals |
[frames] | no frames]

# Module ecefLocals

(INTERNAL) ECEF to local coodinate conversions, separated from module `ecef` to defer importing the latter into `CartesianBase` and `LatLonBase`.

Version: 25.04.28

Classes
| _EcefLocal (INTERNAL) Base class for `CartesianBase`, `Ecef9Tuple` and `LatLonBase`, providing ECEF to local coordinate conversions.

Variables
| __all__ = `_ALL_LAZY.ecefLocals`